@@ -7,7 +7,7 @@ from urllib.parse import urlparse
 from .image import url2mime
 
 
-__version__ = '0.8.1'
+__version__ = '0.9.0'
 
 renderers: Dict = {}
 
@@ -144,6 +144,28 @@ class Embed(BaseContainer):
         return f'<div class="embed-wrapper {provider_name.lower()}-wrapper"><figure>{html}</figure></div>'  # noqa: E501
 
 
+class CodeBlock(BaseNode):
+    type = "code_block"
+
+    def is_renderable(self, node):
+        renderable = False
+        content = node.get("content", [])
+        if content:
+            text = content[0]
+            renderable = bool(text.get("text", ""))
+        return renderable
+
+    def inner_render(self, node):
+        attrs = node.get("attrs", {})
+        language = attrs.get("language", "")
+        content = node.get("content", {})[0]
+        text = e(content.get("text", ""))
+        html = ""
+        if language:
+            html = f'<div class="hljs"><pre data-lang="{language}">{text}</pre></div>' # noqa: E501
+        return html
+
+
 class Title(BaseContainer):
     type = "title"
     wrap_tag: str = "h1"
